genomeNotebook
================

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

## Install

    pip install genomenotebook

## How to use

Create a simple genome browser with a search bar. The sequence appears
when zooming in.

``` python
g=GenomeBrowser(genome_path="data/MG1655_U00096.fasta",
                gff_path="data/MG1655_U00096.gff3")
g.show()
```

  <div id="6b515b6f-a015-4aab-922d-c569e7f79b51" data-root-id="p1084" style="display: contents;"></div>

    Unable to display output for mime type(s): application/javascript, application/vnd.bokehjs_exec.v0+json
